Module: DFuzz
- Defined in:
- lib/dfuzz/generator18.rb,
lib/dfuzz.rb,
lib/dfuzz/char.rb,
lib/dfuzz/block.rb,
lib/dfuzz/fudge.rb,
lib/dfuzz/string.rb,
lib/dfuzz/integer.rb,
lib/dfuzz/diagonal.rb,
lib/dfuzz/generator.rb,
lib/dfuzz/sequential.rb
Overview
– $Idaemons: /home/cvs/rb/generator.rb,v 1.8 2001/10/03 08:54:32 knu Exp $ $RoughId: generator.rb,v 1.10 2003/10/14 19:36:58 knu Exp $ $Id: generator.rb,v 1.12 2005/12/31 02:56:46 ocean Exp $ ++
generator.rb: convert an internal iterator to an external one
Copyright © 2001,2003 Akinori MUSHA <[email protected]>
All rights reserved. You can redistribute and/or modify it under the same terms as Ruby.
Overview
This library provides the Generator class, which converts an internal iterator (i.e. an Enumerable object) to an external iterator. In that form, you can roll many iterators independently.
The SyncEnumerator class, which is implemented using Generator, makes it easy to roll many Enumerable objects synchronously.
See the respective classes for examples of usage.
Defined Under Namespace
Classes: Block, Byte, Char, Diagonal, EmailAddress, Fudge, Generator, Integer, Long, LongLong, Sequential, Short, String, SyncEnumerator